@@ -30,9 +30,12 @@ display(r)
 from azdsdr.readers import KustoReader
 
 cluster = "https://cgadataout.kusto.windows.net"
-db      = "AIPDD_Usage"
+db      = "pii"
 kr = KustoReader(cluster=cluster,db=db)
 
+#%% test list all tables 
+kr.list_tables(folder_name='prodev')
+
 #%% 
 kql = '''
 cluster('Cgadataout').database('Starlight').FACT_ACR_Publish
